import punycode from 'punycode';

const unicodeLength = (string) => {
    if (!string || typeof string !== 'string')
        return 0;
    return punycode.ucs2.decode(string).length;
};
const timeToInt = (time) => parseInt(time.replace(':', ''), 10);

const REGEX_EMAIL = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
const REGEX_INT = /^\d+$/;
const REGEX_FLOAT = /^\d+(\.\d+)?$/;
const REGEX_PHONE = /^(?=.{2,50}$)[/\-.()+\s\d–]*\d{2,}[/\-.()+\s\d–]*$/;
const REGEX_URL = /^(?:https?:\/\/)?((?:[^\u0000-\u007F]|[\w-])+\.(?:(?:[^\u0000-\u007F]|[\w-]){2,}\.)*(?:[^\u0000-\u007F]|[a-zA-Z])+)(?::\d+)?(\/(?:(?:[^\u0000-\u007F]|[\w/.,'"@+=!:;=%()-])+)?(?:\.(?:[^\u0000-\u007F]|[\w-])+)?)?((?:\?|#)\S+)?$/;
const REGEX_LOWERCASE = /[a-z]+/;
const REGEX_UPPERCASE = /[A-Z]+/;
const REGEX_NUMBERS = /\d+/;
const REGEX_SPECIAL = /[^A-Za-z\d]+/;
const REGEX_TIME = /^\d{2}:\d{2}$/;
const isEmpty = (value) => typeof value === 'undefined' || value === null;
const isRequired = (value) => {
    if (isEmpty(value))
        return false;
    if (Array.isArray(value))
        return value.length !== 0;
    switch (typeof (value)) {
        case 'string': return unicodeLength(value) !== 0;
        case 'object': return JSON.stringify(value) !== '{}';
        case 'boolean': return value;
        case 'number': return true;
        default: return Boolean(value);
    }
};
const isLength = (value = '', min = 0, max = Infinity) => {
    if (isEmpty(value))
        return false;
    const length = Array.isArray(value) ? value.length : unicodeLength(value);
    return (max >= length) && (length >= min);
};
const isRegex = (value, regex) => regex.test(value);
const isEmail = (value) => isRegex(value, REGEX_EMAIL);
const isMostLikelyEmail = (value) => Boolean(value && value.includes('.') && value.includes('@') && isLength(value, 7));
const isPhone = (value) => isRegex(value, REGEX_PHONE);
const isUrl = (value) => isRegex(value, REGEX_URL);
const isInt = (value) => isRegex(value, REGEX_INT);
const isNumber = (value) => isRegex(value, REGEX_FLOAT);
const isEqual = (value, prop) => (value === prop);
const isOneOf = (value, ...props) => props.includes(value);
const isShortText = (value) => isLength(value, 2, 250);
const isLongText = (value) => isLength(value, 2, 5000);
const hasPasswordLength = (value) => isLength(value, 8);
const hasLowerCase = (value) => isRegex(value, REGEX_LOWERCASE);
const hasUpperCase = (value) => isRegex(value, REGEX_UPPERCASE);
const hasNumbers = (value) => isRegex(value, REGEX_NUMBERS);
const hasSpecialCharacters = (value) => isRegex(value, REGEX_SPECIAL);
const isPassword = (value) => ([
    hasPasswordLength,
    hasLowerCase,
    hasUpperCase,
    hasNumbers,
    hasSpecialCharacters,
].every((fn) => fn(value)));
const isTime = (value, min = '00:00', max = '23:59') => {
    if (!isRegex(value, REGEX_TIME))
        return false;
    const valueInt = timeToInt(value);
    return valueInt >= timeToInt(min) && valueInt <= timeToInt(max);
};

export { hasLowerCase, hasNumbers, hasPasswordLength, hasSpecialCharacters, hasUpperCase, isEmail, isEmpty, isEqual, isInt, isLength, isLongText, isMostLikelyEmail, isNumber, isOneOf, isPassword, isPhone, isRegex, isRequired, isShortText, isTime, isUrl };
//# sourceMappingURL=index.js.map
